@@ -2,7 +2,7 @@ test_that("rel_try() with reason", {
   withr::local_envvar(DUCKPLYR_FALLBACK_INFO = TRUE, DUCKPLYR_FORCE = FALSE)
 
   expect_snapshot({
-    rel_try(
+    rel_try(NULL,
       "Not affected" = FALSE,
       "Affected" = TRUE,
       {
